package refTests;

import org.junit.Assert;
import org.junit.Test;

import fr.cnes.celestlab.celestlabx.stela.Extrapolation;
import fr.cnes.celestlab.celestlabx.stela.ExtrapolationResults;

public class Test03_CLx_stelaDeriv extends RefTests {

	/**
	 * Equivalent to Scilab test CLx_stela_deriv.tst - test 1
	 * @throws Exception 
	 */
	@Test
	public void test01() throws Exception {
		initStela();

		// Dates cjd (TREF) for propagation
		double[] delta_t = new double[] { 0.0, 86400.0, 172800.0, 259200.0,
				345600.0, 432000.0, 518400.0, 604800.0, 691200.0, 777600.0,
				864000.0 };

		// Extrapolation
		Extrapolation extrapolation = new Extrapolation();
		extrapolation.run(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		
		ExtrapolationResults results = extrapolation.getExtrapolationResults();

		double[][] x = results.getMeanParamMatrix();

		// Expected value at delta_t = 10 (days)
		double[] dxdt11_expected = new double[] { -3.988196455198828e-05, -4.126931689280668e-09,
				5.225329121172702e-08, -2.911396167101557e-10,
				-6.442275096851301e-09, 0.0001629719141198481 };
		
		// Compute derivatives
		double[] cjd = new double[delta_t.length];
		for (int k = 0; k < delta_t.length; k++) {
			cjd[k] = cjd0 + delta_t[k] / 86400;
		}
		double[][] result = CLx_stela_deriv(cjd, x, params, res, ut1_tref, tt_tref);

		double[] dxdt11_res = result[result.length - 1];
		
		// Compare Res to Ref
		Assert.assertArrayEquals(dxdt11_expected, dxdt11_res, 1.0e-15);

	}
}
