package refTests;

import org.junit.Assert;
import org.junit.Test;

import fr.cnes.celestlab.celestlabx.stela.ExtrapolationResults;

public class Test06_CLx_stelaExtrapModifiedParam extends RefTests {

	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 1
	 * @throws Exception 
	 */
	@Test
	public void test01() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		String[] invString = new String[] { "Sun" };
		params.addStringArray("thirdBody_bodies", invString);

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}

	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 2
	 * @throws Exception 
	 */
	@Test
	public void test02() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		params.addString("drag_coefType", "cook");

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}

	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 3
	 * @throws Exception 
	 */
	@Test
	public void test03() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		params.addBoolean("drag_enabled", false);

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}

	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 4
	 * @throws Exception 
	 */
	@Test
	public void test04() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		params.addString("appAcc_refFrame", "MOD");

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}

	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 5
	 * @throws Exception 
	 */
	@Test
	public void test05() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		params.addString("appAcc_refFrame", "CIRS");

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}
	
	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 6
	 * @throws Exception 
	 */
	@Test
	public void test06() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		params.addBoolean("thirdBody_enabled", false);

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}

	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 7
	 * @throws Exception 
	 */
	@Test
	public void test07() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		params.addBoolean("srp_enabled", false);

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}

	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 8
	 * @throws Exception 
	 */
	@Test
	public void test08() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		params.addDouble("mass", 1000.0);

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}

	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 9
	 * @throws Exception 
	 */
	@Test
	public void test09() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		params.addDouble("drag_area", 30.0);

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}

	/**
	 * Equivalent to Scilab test CLx_stela_extrap_modified_params.tst - test 10
	 * @throws Exception 
	 */
	@Test
	public void test10() throws Exception {
		initStela();

		params = params_backup;

		// Extrapolation with default params
		ExtrapolationResults unmodRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] defaultX = unmodRes.getMeanParamMatrix();

		// Modify parameters
		params.addString("drag_solarActivityType", "variable");

		// Extrapolation with modified params
		ExtrapolationResults modRes = CLx_stela_extrap(cjd0, x0, delta_t, params, res, ut1_tref, tt_tref);
		double[][] newX = modRes.getMeanParamMatrix();

		// Compare Res to Ref
		Assert.assertTrue(newX != defaultX);
	}

}
